@@ -2,7 +2,7 @@
 * file.cpp: File management
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: file.cpp,v 1.1 2001/10/06 21:23:36 bozo Exp $
+* $Id: file.cpp,v 1.2 2001/11/27 15:33:57 bozo Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -234,6 +234,27 @@ int C_File::Seek(s64 iOffset, int iStartPos)
 
 
 
+//------------------------------------------------------------------------------
+// 
+//------------------------------------------------------------------------------
+//
+//------------------------------------------------------------------------------
+bool C_File::Exists() const
+{
+  FILE* hFd = fopen(m_strPath.GetString(), "r");
+
+  if(hFd)
+  {
+    fclose(hFd);
+    return true;
+  }
+  else
+  {
+    return false;
+  }
+}
+
+
 //------------------------------------------------------------------------------
 // 
 //------------------------------------------------------------------------------
